"use strict";

var logger = require('./../logger');

/**
 * Object representing information needed for constructing {@link CustomMap}
 * objects.
 */
function CustomMapOptions(params) {
  if (params.element === undefined) {
    throw new Error("element must be defined");
  }
  this.setElement(params.element);
  this.setConfiguration(params.configuration);
  this.setProject(params.project);
  this.setProjectId(params.projectId);

  if (params.markerOptimization !== undefined) {
    if (typeof params.markerOptimization === "boolean") {
      this._markerOptimization = params.markerOptimization;
    } else {
      logger.warn("markerOptimization must be of type boolean");
      this._markerOptimization = true;
    }
  } else {
    this._markerOptimization = true;
  }

  if (params.bigLogo !== undefined) {
    if (typeof params.bigLogo === "boolean") {
      this._bigLogo = params.bigLogo;
    } else {
      logger.warn("bigLogo must be of type boolean");
      this._bigLogo = false;
    }
  } else {
    this._bigLogo = false;
  }

  if (params.customTouchInterface !== undefined) {
    if (typeof params.customTouchInterface === "boolean") {
      this.setCustomTouchInterface(params.customTouchInterface);
    } else {
      logger.warn("customTouchInterface must be of type boolean");
      this.setCustomTouchInterface(false);
    }
  } else {
    this.setCustomTouchInterface(false);
  }

  this.setDebug(params.debug);
  this.setPlugins(params.plugins);

}

CustomMapOptions.prototype.isMarkerOptimization = function () {
  return this._markerOptimization;
};

CustomMapOptions.prototype.isBigLogo = function () {
  return this._bigLogo;
};
CustomMapOptions.prototype.isCustomTouchInterface = function () {
  return this._customTouchInterface;
};

CustomMapOptions.prototype.getProject = function () {
  return this._project;
};
CustomMapOptions.prototype.setProject = function (project) {
  this._project = project;
};

CustomMapOptions.prototype.getPlugins = function () {
  return this._plugins;
};
CustomMapOptions.prototype.setPlugins = function (plugins) {
  if (plugins === undefined) {
    plugins = [];
  }
  this._plugins = plugins;
};

CustomMapOptions.prototype.getConfiguration = function () {
  return this._configuration;
};
CustomMapOptions.prototype.setConfiguration = function (configuration) {
  this._configuration = configuration;
};

CustomMapOptions.prototype.getProjectId = function () {
  if (this.getProject() !== undefined) {
    return this.getProject().getProjectId();
  } else {
    return this._projectId;
  }
};
CustomMapOptions.prototype.setProjectId = function (projectId) {
  this._projectId = projectId;
};
CustomMapOptions.prototype.setDebug = function (debug) {
  if (debug !== undefined) {
    if (typeof debug !== "boolean") {
      logger.warn("Params must be boolean");
    }
    this._debug = debug;
  }
};

CustomMapOptions.prototype.setCustomTouchInterface = function (customTouchInterface) {
  this._customTouchInterface = customTouchInterface;
};

CustomMapOptions.prototype.isDebug = function () {
  return this._debug === true;
};

CustomMapOptions.prototype.setElement = function (element) {
  this._element = element;
};
CustomMapOptions.prototype.getElement = function () {
  return this._element;
};

module.exports = CustomMapOptions;
